DSOLocalEquivalentOperation

Struct DSOLocalEquivalentOperation 

pub struct DSOLocalEquivalentOperation<'c> { /* private fields */ }
A dso_local_equivalent operation. Creates a LLVM dso_local_equivalent ptr.

Creates an SSA value containing a pointer to a global value (function or alias to function). It represents a function which is functionally equivalent to a given function, but is always defined in the current linkage unit. The target function may not have extern_weak linkage.

Examples:

llvm.mlir.global external constant @const() : i64 {
  %0 = llvm.mlir.addressof @const : !llvm.ptr
  %1 = llvm.ptrtoint %0 : !llvm.ptr to i64
  %2 = llvm.dso_local_equivalent @func : !llvm.ptr
  %4 = llvm.ptrtoint %2 : !llvm.ptr to i64
  llvm.return %4 : i64
}

Implementations

Source

impl<'c> DSOLocalEquivalentOperation<'c>

pub fn name() -> &'static str

Returns a name.

pub fn as_operation(&self) -> &Operation<'c>

Returns a generic operation.

pub fn builder( context: &'c Context, location: Location<'c>, ) -> DSOLocalEquivalentOperationBuilder<'c, Unset, Unset>

Creates a builder.

pub fn res(&self) -> Result<OperationResult<'c, '_>, Error>

pub fn function_name(&self) -> Result<FlatSymbolRefAttribute<'c>, Error>

pub fn set_function_name(&mut self, value: FlatSymbolRefAttribute<'c>)